==> 2.0.2.tar.gz: ios/Classes/FNetmera.h <==
/**
 * Copyright (c) 2019 Inomera Research.
 * @author Burak Soykal
 */

#import <Foundation/Foundation.h>
#import <Flutter/Flutter.h>
#import <Netmera/Netmera.h>

@interface FNetmera : NSObject

+(void)init:(nullable NSString *)apiKey;
+(void)logging:(BOOL)enabled;
+(void)requestPushNotificationAuthorization;
+(void)setBaseUrl:(nonnull FlutterMethodCall *)call;
+(void)requestPermissionsForLocation;
+(void)setNetmeraMaxActiveRegions:(nonnull FlutterMethodCall *)call;
+(void)enablePopupPresentation;
+(void)disablePopupPresentation;
+(void)enablePush;
+(void)disablePush;
+(void)isPushEnabled:(nonnull FlutterResult)result;
+(void)fetchInbox: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)fetchNextPage:(nonnull FlutterResult)result;
+(void)getExternalId:(nonnull FlutterResult)result;
+(void)countForStatus:(nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)inboxUpdateStatus:(nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)sendEvent:(nonnull FlutterMethodCall *)call;
+(void)updateUser:(nonnull FlutterMethodCall *)call;
+(void)setApiKey:(nonnull FlutterMethodCall *)call;
+(void)handlePushObject: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)setAppGroupName:(nonnull FlutterMethodCall *)call;
+(void)turnOffSendingEventAndUserUpdate;
+(void)setPushDelegate:(nonnull NSObject<NetmeraPushDelegate> *)delegate;
+(void)fetchCategory: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)fetchNextCategoryPage:(nonnull FlutterResult)result;
+(void)handleLastMessage: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)handleInteractiveAction: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)updateStatusByCategories: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)updateAll: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;

@end

==> 2.1.2-dev.tar.gz: ios/Classes/FNetmera.h <==
/**
 * Copyright (c) 2019 Inomera Research.
 * @author Burak Soykal
 */

#import <Foundation/Foundation.h>
#import <Flutter/Flutter.h>
#import <Netmera/Netmera.h>

@interface FNetmera : NSObject

+(void)initNetmera:(nullable NSString *)apiKey;
+(void)logging:(BOOL)enabled;
+(void)requestPushNotificationAuthorization;
+(void)setBaseUrl:(nonnull FlutterMethodCall *)call;
+(void)requestPermissionsForLocation;
+(void)setNetmeraMaxActiveRegions:(nonnull FlutterMethodCall *)call;
+(void)enablePopupPresentation;
+(void)disablePopupPresentation;
+(void)enablePush;
+(void)disablePush;
+(void)isPushEnabled:(nonnull FlutterResult)result;
+(void)fetchInbox: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)fetchNextPage:(nonnull FlutterResult)result;
+(void)getExternalId:(nonnull FlutterResult)result;
+(void)countForStatus:(nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)inboxUpdateStatus:(nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)sendEvent:(nonnull FlutterMethodCall *)call;
+(void)updateUser:(nonnull FlutterMethodCall *)call;
+(void)setApiKey:(nonnull FlutterMethodCall *)call;
+(void)handlePushObject: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)setAppGroupName:(nonnull FlutterMethodCall *)call;
+(void)turnOffSendingEventAndUserUpdate;
+(void)setPushDelegate:(nonnull NSObject<NetmeraPushDelegate> *)delegate;
+(void)fetchCategory: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)fetchNextCategoryPage:(nonnull FlutterResult)result;
+(void)handleLastMessage: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)handleInteractiveAction: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)updateStatusByCategories: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;
+(void)updateAll: (nonnull FlutterMethodCall *)call result: (nonnull FlutterResult)result;

@end
